@@ -1,12 +1,12 @@
-//@line 37 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 37 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 
 // XXX Toolkit-specific preferences should be moved into toolkit.js
 
-//@line 41 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 41 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 
-//@line 44 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 44 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 
-//@line 50 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 50 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 
 pref("general.startup.browser", true);
 
@@ -133,12 +133,12 @@ pref("keyword.URL", "chrome://browser-region/locale/region.properties");
 
 pref("general.useragent.locale", "en-US");
 pref("general.skins.selectedSkin", "classic/1.0");
-pref("general.useragent.extra.firefox", "Firefox/3.0.4");
+pref("general.useragent.extra.firefox", "Firefox/3.0.5");
 
 pref("general.smoothScroll", false);
-//@line 180 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 180 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 pref("general.autoScroll", false);
-//@line 184 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 184 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 
 // Whether or not the application should check at startup each time if it 
 // is the default browser.
@@ -159,11 +159,11 @@ pref("browser.warnOnRestart", true);
 pref("browser.fullscreen.autohide", true);
 pref("browser.fullscreen.animateUp", 1);
 
-//@line 205 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 205 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 pref("browser.urlbar.clickSelectsAll", false);
-//@line 210 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 210 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 pref("browser.urlbar.doubleClickSelectsAll", true);
-//@line 214 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 214 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 pref("browser.urlbar.autoFill", false);
 pref("browser.urlbar.matchOnlyTyped", false);
 // 0: Match anywhere (e.g., middle of words)
@@ -299,9 +299,9 @@ pref("browser.bookmarks.max_backups",             5);
 
 // Scripts & Windows prefs
 pref("dom.disable_open_during_load",              true);
-//@line 353 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 353 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 pref("javascript.options.showInConsole",          false);
-//@line 355 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 355 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 
 // Make the status bar reliably present and unaffected by pages
 pref("dom.disable_window_open_feature.status",    true);
@@ -356,7 +356,7 @@ pref("intl.menuitems.alwaysappendaccesskeys","chrome://global/locale/intl.proper
 pref("intl.menuitems.insertseparatorbeforeaccesskeys","chrome://global/locale/intl.properties");
 
 // 0=lines, 1=pages, 2=history , 3=text size
-//@line 423 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 423 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 pref("mousewheel.withshiftkey.action",2);
 pref("mousewheel.withshiftkey.sysnumlines",false);
 pref("mousewheel.withshiftkey.numlines",1);
@@ -366,7 +366,7 @@ pref("mousewheel.withaltkey.numlines",1);
 pref("mousewheel.withmetakey.action",0);
 pref("mousewheel.withmetakey.sysnumlines",true);
 pref("mousewheel.withmetakey.numlines",1);
-//@line 433 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 433 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 pref("mousewheel.withcontrolkey.action",3);
 pref("mousewheel.withcontrolkey.sysnumlines",false);
 pref("mousewheel.withcontrolkey.numlines",1);
@@ -426,11 +426,11 @@ pref("pfs.datasource.url", "https://pfs.mozilla.org/plugins/PluginFinderService.
 // by default we show an infobar message when pages require plugins the user has not installed
 pref("plugins.hide_infobar_for_missing_plugin", false);
 
-//@line 495 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 495 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 pref("browser.preferences.instantApply", true);
-//@line 500 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 500 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 pref("browser.preferences.animateFadeIn", false);
-//@line 502 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 502 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 
 pref("browser.download.show_plugins_in_list", true);
 pref("browser.download.hide_plugins_without_extensions", true);
@@ -443,9 +443,9 @@ pref("bidi.browser.ui", false);
 // 0 goes Back/Forward
 // 1 act like PgUp/PgDown
 // 2 and other values, nothing
-//@line 515 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 515 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 pref("browser.backspace_action", 2);
-//@line 519 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 519 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 
 // this will automatically enable inline spellchecking (if it is available) for
 // editable elements in HTML
@@ -518,7 +518,7 @@ pref("gecko.handlerService.schemes.mailto.3.uriTemplate", "chrome://browser-regi
 // By default, we don't want protocol/content handlers to be registered from a different host, see bug 402287
 pref("gecko.handlerService.allowRegisterFromDifferentHost", false);
 
-//@line 592 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 592 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 // Safe browsing does nothing unless this pref is set
 pref("browser.safebrowsing.enabled", true);
 
@@ -526,16 +526,16 @@ pref("browser.safebrowsing.enabled", true);
 pref("browser.safebrowsing.malware.enabled", true);
 
 // Non-enhanced mode (local url lists) URL list to check for updates
-pref("browser.safebrowsing.provider.0.updateURL", "http://safebrowsing.clients.google.com/safebrowsing/downloads?client={moz:client}&appver={moz:version}&pver=2.1");
+pref("browser.safebrowsing.provider.0.updateURL", "http://safebrowsing.clients.google.com/safebrowsing/downloads?client={moz:client}&appver={moz:version}&pver=2.2");
 
 pref("browser.safebrowsing.dataProvider", 0);
 
 // Does the provider name need to be localizable?
 pref("browser.safebrowsing.provider.0.name", "Google");
 pref("browser.safebrowsing.provider.0.lookupURL", "http://safebrowsing.clients.google.com/safebrowsing/lookup?sourceid=firefox-antiphish&features=TrustRank&client={moz:client}&appver={moz:version}&");
-pref("browser.safebrowsing.provider.0.keyURL", "https://sb-ssl.google.com/safebrowsing/newkey?client={moz:client}&appver={moz:version}&pver=2.1");
+pref("browser.safebrowsing.provider.0.keyURL", "https://sb-ssl.google.com/safebrowsing/newkey?client={moz:client}&appver={moz:version}&pver=2.2");
 pref("browser.safebrowsing.provider.0.reportURL", "http://safebrowsing.clients.google.com/safebrowsing/report?");
-pref("browser.safebrowsing.provider.0.gethashURL", "http://safebrowsing.clients.google.com/safebrowsing/gethash?client={moz:client}&appver={moz:version}&pver=2.1");
+pref("browser.safebrowsing.provider.0.gethashURL", "http://safebrowsing.clients.google.com/safebrowsing/gethash?client={moz:client}&appver={moz:version}&pver=2.2");
 
 // privacy policy -- Both url and fallbackurl must exist, although they may
 // point to the same file.  fallbackurl must be a chrome url
@@ -565,27 +565,23 @@ pref("urlclassifier.gethashtables", "goog-phish-shavar,goog-malware-shavar");
 // the database.
 pref("urlclassifier.confirm-age", 2700);
 
-//@line 644 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 644 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 
 // Maximum size of the sqlite3 cache during an update, in bytes
-//@line 647 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 647 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 pref("urlclassifier.updatecachemax", 104857600);
-//@line 651 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 651 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 
 // URL for checking the reason for a malware warning.
 pref("browser.safebrowsing.malware.reportURL", "http://safebrowsing.clients.google.com/safebrowsing/diagnostic?client=%NAME%&hl=%LOCALE%&site=");
 
-//@line 656 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 656 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 
-// defaults to true on Windows and Mac, because the installer shows this
-//@line 663 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
-pref("browser.EULA.3.accepted", false);
-//@line 665 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
-
-// if we rev the EULA again, we should bump this so users agree to the new EULA
 pref("browser.EULA.version", 3);
+pref("browser.rights.version", 3);
+pref("browser.rights.3.shown", false);
 
-//@line 672 "/export/home/mozilla/uild/firefox-3.0.4/src/mozilla/browser/app/profile/firefox.js"
+//@line 665 "/export/home/mozilla/uild/firefox-3.0.5/src/mozilla/browser/app/profile/firefox.js"
 
 pref("browser.sessionstore.enabled", true);
 pref("browser.sessionstore.resume_from_crash", true);
